//! @file 
//! @brief File containing the Test Class and the Test Methods
//!

#include <iostream>
#include <cppunit/TestCase.h>
#include <cppunit/TestFixture.h>
#include <cppunit/ui/text/TextTestRunner.h>
#include <cppunit/extensions/HelperMacros.h>
#include <cppunit/extensions/TestFactoryRegistry.h>
#include <cppunit/TestResult.h>
#include <cppunit/TestResultCollector.h>
#include <cppunit/TestRunner.h>
#include <cppunit/BriefTestProgressListener.h>
#include <cppunit/CompilerOutputter.h>
#include <cppunit/XmlOutputter.h>
#include "Calculations.h"
using namespace CppUnit;
using namespace std;

//! Test Class for the Calculations class
//! It must be a subclass of CppUnit::TestFixture
//! It then uses CPPUNIT_TEST_SUITE() to create the test suite, and CPPUNIT_TEST() to include the test methods in the test suite. 
//! CPPUNIT_TEST_SUITE_REGISTRATION() is then used to register the test class in the test registry.
class TestCalculations : public CppUnit::TestFixture

{
	
    CPPUNIT_TEST_SUITE(TestCalculations);//declare the test suite
		CPPUNIT_TEST(testDivision);//test the Division method
		CPPUNIT_TEST(testMultiplication);//test the multiplication method
		CPPUNIT_TEST(testAddition);//test the addition method
		CPPUNIT_TEST(testSubtraction);//test the addition method
	CPPUNIT_TEST_SUITE_END();//end of test suite declaration

public:

    void setUp(void);
    void tearDown(void);

protected:
	void testDivision(void);
    void testAddition(void);
    void testMultiplication(void);
	void testSubtraction(void);
private:

    Calculations *CalcObject;

};

//!Register for running the test
CPPUNIT_TEST_SUITE_REGISTRATION(TestCalculations);//most important


//! test method to test the Addition() method of the Calculations class 
//! Test Case: 3+3=6
void TestCalculations::testAddition(void)
{
    CPPUNIT_ASSERT(6 == CalcObject->Addition(3,3));
}

//! test method to test the Multiplication() method of the Calculations class 
//! Test Case: 2*3=6
void TestCalculations::testMultiplication(void)
{
    CPPUNIT_ASSERT(6 == CalcObject->Multiplication(2,3));
}

//! test method to test the Division() method of the Calculations class 
//! Test Case: 9/3=3
void TestCalculations::testDivision(void)
{
    CPPUNIT_ASSERT(3 == CalcObject->Division(9,3));
}

//! test method to test the Subtraction() method of the Calculations class 
//! Test Case: 9-3=6
void TestCalculations::testSubtraction(void)
{
    CPPUNIT_ASSERT(6 == CalcObject->Subtraction(9,3));
}

//! setUp() method that is executed before all the test cases that the test class includes 
void TestCalculations::setUp(void)

{
    CalcObject = new Calculations();
}

//! tearDown() method that is executed after all the test cases that the test class includes 
void TestCalculations::tearDown(void)

{

    delete CalcObject;
	
}

 